import React from 'react';
import { useRequests } from './requests.js';
import styled from 'styled-components';
const SfToolbarInfo = styled.div `
  background-color: #222222;
  color: #eeeeee;
  font-size: 0.8rem;
  display: ${(props) => (props.hasRequests ? 'block' : 'none')};
  padding: 10px;
  max-width: 525px;
  max-height: 480px;
  word-wrap: break-word;
  overflow-x: hidden;
  overflow-y: auto;
  position: absolute;
  bottom: 36px;
  right: 0;
`;
const UrlTd = styled.td `
  max-width: 250px;
  line-height: 9px;
  overflow: hidden;
  text-overflow: ellipsis;
  word-wrap: break-word;
  white-space: nowrap;
`;
const A = styled.a `
  color: #99cdd8;
  text-decoration: underline;
`;
export const RequestsTable = () => {
    const { responses, hasResponses, reset } = useRequests();
    if (!hasResponses) {
        return null;
    }
    const getTitle = (length) => `${length} AJAX request${length > 1 ? 's' : ''}`;
    return (React.createElement(SfToolbarInfo, { className: 'sf-toolbar-info', hasRequests: hasResponses },
        React.createElement("header", null,
            getTitle(responses.length),
            " (",
            React.createElement(A, { href: '#', onClick: () => reset() }, "Clear"),
            ")"),
        React.createElement("table", null,
            React.createElement("thead", null,
                React.createElement("tr", null,
                    React.createElement("th", null, "#"),
                    React.createElement("th", null, "Profile"),
                    React.createElement("th", null, "Method"),
                    React.createElement("th", null, "Type"),
                    React.createElement("th", null, "Status"),
                    React.createElement("th", null, "URL"))),
            React.createElement("tbody", null, responses.map((elem, idx) => {
                return (React.createElement("tr", { key: idx },
                    React.createElement("td", null, idx + 1),
                    React.createElement("td", null,
                        React.createElement(A, { href: elem.profiler, target: '_blank' }, elem.token)),
                    React.createElement("td", null, elem.method),
                    React.createElement("td", null, elem.type),
                    React.createElement("td", null, elem.status),
                    React.createElement(UrlTd, { title: elem.url },
                        React.createElement(A, { href: elem.url, target: '_blank' }, elem.url))));
            })))));
};
//# sourceMappingURL=requests-table.js.map