import React, { createContext, useContext, useEffect, useState } from 'react';
import { BatchInterceptor } from '@mswjs/interceptors';
import browserInterceptors from '@mswjs/interceptors/lib/presets/browser.js';
const RequestsContext = createContext(undefined);
const interceptor = new BatchInterceptor({
    name: 'symfony-debug',
    interceptors: browserInterceptors,
});
function hasProfilerHeaders(headers, tokenLinkHeader, tokenHeader) {
    return headers.has(tokenLinkHeader) && headers.has(tokenHeader);
}
export const RequestsProvider = ({ tokenHeader, tokenLinkHeader, children }) => {
    const [responses, setResponses] = useState([]);
    /**
     * @param {Response} response
     */
    const onResponse = (response) => {
        const headers = response.headers;
        if (hasProfilerHeaders(headers, tokenLinkHeader, tokenHeader)) {
            const requestInfo = {
                error: false,
                url: response.url,
                method: '?',
                type: response.type,
                status: response.status,
                token: headers.get(tokenHeader) ?? '',
                profiler: headers.get(tokenLinkHeader) ?? '',
            };
            addResponse(requestInfo);
        }
    };
    useEffect(() => {
        interceptor.apply();
        interceptor.on('response', onResponse);
    }, [onResponse]);
    const reset = () => setResponses([]);
    const addResponse = (requestInfo) => setResponses((prevState) => [requestInfo, ...prevState]);
    const value = {
        responses,
        reset,
        addResponse,
        hasResponses: !!responses.length,
    };
    return React.createElement(RequestsContext.Provider, { value: value }, children);
};
export const useRequests = () => {
    const context = useContext(RequestsContext);
    if (context === undefined) {
        throw new Error(`Context undefined. Are you missing a Provider?`);
    }
    return context;
};
//# sourceMappingURL=requests.js.map